/*

  Copyright (C) 2001 StrmnNrmn

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef __DUMMY_H__
#define __DUMMY_H__

#define Memory_VI_GetRegister( reg )		*g_GraphicsInfo.x##reg


// These are simply dummy functions to help the project to compile
class RomID
{
	public: 
		RomID() {}
		RomID( u32 crc1, u32 crc2, u8 country_id )
		{
			CRC[0] = crc1;
			CRC[1] = crc2;
			CountryID = country_id;
		}

		bool operator==( const RomID & id ) const
		{
			return CRC[0]		== id.CRC[0] &&
				   CRC[1]		== id.CRC[1] &&
				   CountryID	== id.CountryID;
		}
		
		u32		CRC[2];
		u8		CountryID;
};


#pragma pack(1)
struct ROMHeader
{
	u8		x1, x2, x3, x4;
	u32		ClockRate;
	u32		BootAddress;
	u32		Release;
	u32		CRC1;
	u32		CRC2;
	u32		Unknown0;
	u32		Unknown1;
	s8		Name[20];
	u32		Unknown2;
	u16		Unknown3;
	u8		Unknown4;
	u8		Manufacturer;
	u16		CartID;
	s8		CountryID;
	u8		Unknown5;
};
#pragma pack()


//*****************************************************************************
// Configurable settings for a rom
//*****************************************************************************
struct RomSettings
{
	TCHAR	szGameName[50+1];		// Friendly name for this rom
	
	// Config stuff
	DWORD	ucode;
	TCHAR	szComment[100+1];
	TCHAR	szInfo[100+1];
	BOOL	bDisablePatches;
	BOOL	bDisableTextureCRC;
	BOOL	bDisableEeprom;
	BOOL	bIncTexRectEdge;
	BOOL	bDisableSpeedSync;
	BOOL	bDisableDynarec;
	BOOL	bExpansionPak;
	DWORD	dwEepromSize;
	DWORD	dwRescanCount;

};

//*****************************************************************************
//
//*****************************************************************************
typedef struct 
{
	TCHAR		szFileName[MAX_PATH+1];
	RomID		mRomID;					// The RomID (unique to this rom)

	ROMHeader	rh;						// Copy of the ROM header, correctly byteswapped
	RomSettings settings;				// Settings for this rom
	u32			nTvType;				// OS_TV_NTSC etc

} RomInfo;

extern RomInfo g_ROM;



inline static void Dump_EnsureExists(LPCTSTR szPath)
{
	TCHAR szPathParent[MAX_PATH+1];

	if (PathIsDirectory(szPath))
	{
		return;
	}

	// Make sure parent exists, 
	lstrcpyn(szPathParent, szPath, MAX_PATH);
	PathRemoveBackslash(szPathParent);
	PathRemoveFileSpec(szPathParent);
	Dump_EnsureExists(szPathParent);


	CreateDirectory(szPath, NULL);

	OutputDebugString( szPath );
	OutputDebugString( " created for dumping.\n" );
}

// Initialise the directory where files are dumped
inline void Dump_GetDumpDirectory(LPTSTR szFilePath, LPCTSTR szSubDir)
{
	// Appends szBase to the global dump base. Stores in szFilePath
static TCHAR g_szDumpDir[MAX_PATH+1] = TEXT("");


	if (lstrlen(g_szDumpDir) == 0)
	{
		// Initialise
		PathCombine(g_szDumpDir, g_szDaedalusExeDir, TEXT("Dumps"));
	}

	// If a subdirectory was specified, append 
	if (lstrlen(szSubDir) > 0)
		PathCombine(szFilePath, g_szDumpDir, szSubDir);
	else
		lstrcpyn(szFilePath, g_szDumpDir, MAX_PATH);

	Dump_EnsureExists(szFilePath);

}


inline HANDLE Debug_CreateDumpFile( LPCTSTR szFileName )
{
	HANDLE hFile;
//	DBGConsole_Msg(0, "Creating Dump file '%s'", szFileName);

	hFile = CreateFile(szFileName,		// open the file 
			GENERIC_WRITE,              // open for writing 
			0,                          // do not share 
			NULL,                       // no security 
			CREATE_ALWAYS,              // replace any existing file
			FILE_ATTRIBUTE_NORMAL,      // normal file 
			NULL);                      // no attr. template 

	return hFile;
}

inline void Debug_CloseDumpFile( HANDLE & hFile )
{
	CloseHandle(hFile);
	hFile = INVALID_HANDLE_VALUE;
}

inline void Debug_DumpLine( HANDLE hFile, LPCTSTR szFormat, va_list va )
{
 	DWORD dwNumWritten;
    TCHAR szBuffer[1000];

	// For float conversions, don't use wvsprintf
	vsprintf(szBuffer, szFormat, va);
	lstrcat(szBuffer, "\r\n");	
	WriteFile(hFile, szBuffer, lstrlen(szBuffer), &dwNumWritten, NULL);

}

//*****************************************************************************
// Reset to default values
//*****************************************************************************
inline void	ROM_ResetSettings( RomSettings * p_settings )
{
	strcpy(p_settings->szGameName, "");
	strcpy(p_settings->szComment, "");
	strcpy(p_settings->szInfo, "");

	p_settings->ucode = 5;				// Most new games are ucode 5 - thanks CyRUS64
	p_settings->bDisablePatches = false;
	p_settings->bDisableTextureCRC = false;
	p_settings->bDisableEeprom = false;
	p_settings->bIncTexRectEdge = false;
	p_settings->bDisableSpeedSync = false;
	p_settings->bDisableDynarec = false;
	p_settings->bExpansionPak = false;
	p_settings->dwEepromSize = 2048;
	p_settings->dwRescanCount = 0;

}



#endif